@@ -1,7 +1,7 @@
 import copy
 import math
 
-class optiEncoder:
+class Encoder:
     def __init__(self, lst):
         self.lst = list(lst)
         self.categories = set(self.lst)
